import React from 'react';

import HeadView from '../view/HeadView';
import TableBtnView from '../view/TableBtnView';
import { Input, Button, DatePicker, Divider, message, Popconfirm, Select, Badge, Tooltip } from 'antd';
import moment from 'moment';
import Fetch from '../fetch';
import TableView from '../view/TableView';
const Option = Select.Option;
function typeOfName(type) {
    switch (type) {
        case 1:
            return "待处理";
        case 2:
            return "已受理";
        case 3:
            return "已反馈";
    }
}
export default class PoliceSecurity extends React.Component {
    constructor(props) {
        super(props);
        this.state = {
            data: [],
            formdata: {
                page: 1,
                size: 10,
                type:3,
            },
            resetKey: Date.now(),
            loading: false
        };
    }

    componentDidMount() {
        document.title = '公安审核';
        this.getData();
    }

    getData = () => {
        const { formdata } = this.state;
        this.setState({ loading: true })
        Fetch.entryQuery({ ...formdata })
            .then(res => {
                console.log(res)
                for (var i = 0; i < res.rows.length; i++) {
                    res.rows[i]['index'] = i + 1;
                }
                this.setState({
                    data: res.rows,
                    loading: false 
                });
            });
    }
    onInputChange = ({ target: { value, name } }) => {
        this.setState(({ formdata }) => ({
            formdata: {
                ...formdata,
                [name]: value
            }
        }))
    }
    showModal = (id) => {
        this.props.history.push("/entry/ExamineEdit/" + id);
    }

    Seaech = () => {
        const { formdata } = this.state;
        Fetch.getSweeping(formdata)
            .then(res => {
                for (var i = 0; i < res.length; i++) {
                    res[i]['index'] = i + 1;
                }
                this.setState({
                    data: res
                });
            });
    }
    Reset = () => {
        this.setState({
            resetKey: Date.now(),
            formdata: {}
        }, this.getData);
    }

    confirm = (e) => {
        console.log(e);
        this.setState({ loading: true })
        Fetch.socialDelete(e).then(res => {
            if (res.code == 0) {
                console.log(res)
                this.setState({ loading: false })
                message.success('删除成功');
                this.getData();
            } else {
                this.setState({ loading: false })
                message.error('删除失败，请联系管理员', 2)
            }
        }
        )
    }
    render() {
        const columns = [{
            title: '申请人',
            dataIndex: 'createrName',
            key: 'createrName'
        }, {
            title: '申请时间',
            dataIndex: 'createTime',
            key: 'createTime',
            render: text => <span>{moment(text).format("YYYY-MM-DD HH:mm")}</span>
        }, {
            title: '申请理由',
            dataIndex: 'reason',
            key: 'reason',
            render: text => <Tooltip title={text}>
                <span width='500px'>{text}</span>
            </Tooltip>
        }, {
            title: '状态',
            dataIndex: 'status',
            key: 'status',
            render: text => (
                text == 1 ? <Badge style={{ backgroundColor: '#6C757C' }} count={'待处理'} /> : text == 2 ? <Badge style={{ backgroundColor: '#F1C40F' }} count={'已受理'} /> : <Badge style={{ backgroundColor: '#2ECC71' }} count={'已反馈'} />
            )
        }, {
            title: '操作',
            key: 'action',
            render: (text, record) => (
                <span>
                    <a onClick={() => this.showModal(record.id)}>审核</a>
                </span>
            ),
        }];
        const { data, loading, resetKey } = this.state;
        return (
            <div className="app-page">
                <HeadView history={this.props.history} />
                <TableBtnView  key={resetKey} style={{marginTop:"20px"}}>
                    <Select
                        style={{ width: 200 }}
                        placeholder="根据举报性质查询"
                        onChange={(value) => this.onInputChange({ target: { name: 'nature', value } })}
                    >
                        <Option value="1">涉黑涉恶违法犯罪行为</Option>
                        <Option value="2">涉黑涉恶违法犯罪保护伞</Option>
                        <Option value="3">其他</Option>
                    </Select>
                    <Input placeholder="根据内容模糊查询" style={{ width: "200px" }} name='content' onChange={this.onInputChange} />
                    <Select
                        style={{ width: 200 }}
                        placeholder="根据状态查询"
                        onChange={(value) => this.onInputChange({ target: { name: 'status', value } })}
                    >
                        <Option value="2">已回复</Option>
                        <Option value="1">待回复</Option>
                    </Select>

                    <DatePicker onChange={(_, value) => this.onInputChange({ target: { name: 'createTime', value } })} placeholder="根据创建时间查询" />
                    <Button type="primary" onClick={this.Seaech}>查询</Button>
                    <Button onClick={this.Reset}>重置</Button>
                </TableBtnView>
                <TableView columns={columns} data={data} pageSize='10' size='default' loading={loading} />
            </div>
        );
    }

}
